Reads the content of a remote file and returns it as a character string,
analogous to cat on the command line.
Examples
if (FALSE) { # \dontrun{
txt <- rclone_cat("myremote:bucket/readme.txt")
cat(txt)
} # }
Reads the content of a remote file and returns it as a character string,
analogous to cat on the command line.
if (FALSE) { # \dontrun{
txt <- rclone_cat("myremote:bucket/readme.txt")
cat(txt)
} # }